@@ -21,6 +21,7 @@
 """Quadratic programming solvers in Python with a unified API."""
 
 from ._internals import available_solvers
+from .active_set import ActiveSet
 from .exceptions import (
     NoSolverSelected,
     ParamError,
@@ -36,24 +37,30 @@ from .solve_qp import solve_problem, solve_qp
 from .solve_unconstrained import solve_unconstrained
 from .solvers import (
     cvxopt_solve_qp,
+    daqp_solve_qp,
     dense_solvers,
     ecos_solve_qp,
     gurobi_solve_qp,
     highs_solve_qp,
+    hpipm_solve_qp,
+    mosek_solve_qp,
     osqp_solve_qp,
+    piqp_solve_qp,
     proxqp_solve_qp,
+    qpalm_solve_qp,
     qpoases_solve_qp,
     qpswift_solve_qp,
     quadprog_solve_qp,
     scs_solve_qp,
     sparse_solvers,
 )
-from .unsupported import mosek_solve_qp, nppro_solve_qp
+from .unsupported import nppro_solve_qp
 from .utils import print_matrix_vector
 
-__version__ = "3.2.0"
+__version__ = "4.1.1"
 
 __all__ = [
+    "ActiveSet",
     "NoSolverSelected",
     "ParamError",
     "Problem",
@@ -65,15 +72,19 @@ __all__ = [
     "__version__",
     "available_solvers",
     "cvxopt_solve_qp",
+    "daqp_solve_qp",
     "dense_solvers",
     "ecos_solve_qp",
     "gurobi_solve_qp",
     "highs_solve_qp",
+    "hpipm_solve_qp",
     "mosek_solve_qp",
     "nppro_solve_qp",
     "osqp_solve_qp",
     "print_matrix_vector",
+    "piqp_solve_qp",
     "proxqp_solve_qp",
+    "qpalm_solve_qp",
     "qpoases_solve_qp",
     "qpswift_solve_qp",
     "quadprog_solve_qp",
