@@ -47,10 +47,11 @@ def split_dual_linear_box(
     Returns
     -------
     :
-        Pair :code:`z, z_box` of linear and box multipliers. Both can be
-        `None` if there is no corresponding constraint.
+        Pair :code:`z, z_box` of linear and box multipliers. Both can be empty
+        arrays if there is no corresponding constraint.
     """
-    z, z_box = None, None
+    z = np.empty((0,))
+    z_box = np.empty((0,))
     if lb is not None and ub is not None:
         n_lb = lb.shape[0]
         n_ub = ub.shape[0]
