@@ -37,6 +37,11 @@ class Solution:
     extras :
         Other outputs, specific to each solver.
 
+    found :
+        True if the solution was found successfully by a solver, False if the
+        solver did not find a solution or detected an unfeasible problem,
+        ``None`` if no solver was run.
+
     problem :
         Quadratic program the solution corresponds to.
 
@@ -80,17 +85,13 @@ class Solution:
 
     problem: Problem
     extras: dict = field(default_factory=dict)
+    found: Optional[bool] = None
     obj: Optional[float] = None
     x: Optional[np.ndarray] = None
     y: Optional[np.ndarray] = None
     z: Optional[np.ndarray] = None
     z_box: Optional[np.ndarray] = None
 
-    @property
-    def found(self) -> bool:
-        """Check whether the solver found a solution."""
-        return self.x is not None
-
     def is_optimal(self, eps_abs: float) -> bool:
         """Check whether the solution is indeed optimal.
 
@@ -134,7 +135,7 @@ class Solution:
         and why this residual will be zero at the optimum.
         """
         _, _, G, h, A, b, lb, ub = self.problem.unpack()
-        if self.x is None:
+        if not self.found or self.x is None:
             return np.inf
         x = self.x
         return max(
@@ -167,7 +168,7 @@ class Solution:
         and why this residual will be zero at the optimum.
         """
         P, q, G, _, A, _, lb, ub = self.problem.unpack()
-        if self.x is None:
+        if not self.found or self.x is None:
             return np.inf
         zeros = np.zeros(self.x.shape)
         Px = P.dot(self.x)
@@ -216,7 +217,7 @@ class Solution:
         and why this gap will be zero at the optimum.
         """
         P, q, _, h, _, b, lb, ub = self.problem.unpack()
-        if self.x is None:
+        if not self.found or self.x is None:
             return np.inf
         xPx = self.x.T.dot(P.dot(self.x))
         qx = q.dot(self.x)
