@@ -77,9 +77,9 @@ def solve_qp(
     b :
         Linear equality vector.
     lb :
-        Lower bound constraint vector.
+        Lower bound constraint vector. Can contain ``-np.inf``.
     ub :
-        Upper bound constraint vector.
+        Upper bound constraint vector. Can contain ``+np.inf``.
     solver :
         Name of the QP solver, to choose in
         :data:`qpsolvers.available_solvers`. This argument is mandatory.
@@ -143,4 +143,4 @@ def solve_qp(
         )
     problem = Problem(P, q, G, h, A, b, lb, ub)
     solution = solve_problem(problem, solver, initvals, verbose, **kwargs)
-    return solution.x
+    return solution.x if solution.found else None
