@@ -20,7 +20,7 @@
 
 """Import available QP solvers."""
 
-from typing import Any, Callable, Dict, Optional, Union
+from typing import Any, Callable, Dict, List, Optional, Union
 
 from numpy import ndarray
 from scipy.sparse import csc_matrix
@@ -28,10 +28,10 @@ from scipy.sparse import csc_matrix
 from ..problem import Problem
 from ..solution import Solution
 
-available_solvers = []
-dense_solvers = []
+available_solvers: List[str] = []
+dense_solvers: List[str] = []
 solve_function: Dict[str, Any] = {}
-sparse_solvers = []
+sparse_solvers: List[str] = []
 
 # Clarabel.rs
 # ===========
@@ -120,6 +120,48 @@ except ImportError:
     pass
 
 
+# DAQP
+# ========
+
+daqp_solve_qp: Optional[
+    Callable[
+        [
+            ndarray,
+            ndarray,
+            Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
+            bool,
+        ],
+        Optional[ndarray],
+    ]
+] = None
+
+daqp_solve_problem: Optional[
+    Callable[
+        [
+            Problem,
+            Optional[ndarray],
+            bool,
+        ],
+        Solution,
+    ]
+] = None
+
+try:
+    from .daqp_ import daqp_solve_problem, daqp_solve_qp
+
+    solve_function["daqp"] = daqp_solve_problem
+    available_solvers.append("daqp")
+    dense_solvers.append("daqp")
+except ImportError:
+    pass
+
+
 # ECOS
 # ====
 
@@ -246,6 +288,92 @@ except ImportError:
     pass
 
 
+# HPIPM
+# =====
+
+hpipm_solve_problem: Optional[
+    Callable[
+        [
+            Problem,
+            Optional[ndarray],
+            str,
+            bool,
+        ],
+        Solution,
+    ]
+] = None
+
+hpipm_solve_qp: Optional[
+    Callable[
+        [
+            Union[ndarray, csc_matrix],
+            ndarray,
+            Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
+            str,
+            bool,
+        ],
+        Optional[ndarray],
+    ]
+] = None
+
+try:
+    from .hpipm_ import hpipm_solve_problem, hpipm_solve_qp
+
+    solve_function["hpipm"] = hpipm_solve_problem
+    available_solvers.append("hpipm")
+    dense_solvers.append("hpipm")
+except ImportError:
+    pass
+
+
+# MOSEK
+# =====
+
+mosek_solve_problem: Optional[
+    Callable[
+        [
+            Problem,
+            Optional[ndarray],
+            bool,
+        ],
+        Solution,
+    ]
+] = None
+
+mosek_solve_qp: Optional[
+    Callable[
+        [
+            Union[ndarray, csc_matrix],
+            ndarray,
+            Union[ndarray, csc_matrix],
+            ndarray,
+            Optional[Union[ndarray, csc_matrix]],
+            Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
+            bool,
+        ],
+        Optional[ndarray],
+    ]
+] = None
+
+try:
+    from .mosek_ import mosek_solve_problem, mosek_solve_qp
+
+    solve_function["mosek"] = mosek_solve_problem
+    available_solvers.append("mosek")
+    sparse_solvers.append("mosek")
+except ImportError:
+    pass
+
+
 # OSQP
 # ====
 
@@ -288,6 +416,51 @@ except ImportError:
     pass
 
 
+# PIQP
+# =======
+
+piqp_solve_qp: Optional[
+    Callable[
+        [
+            Union[ndarray, csc_matrix],
+            Union[ndarray, csc_matrix],
+            Optional[Union[ndarray, csc_matrix]],
+            Optional[Union[ndarray, csc_matrix]],
+            Optional[Union[ndarray, csc_matrix]],
+            Optional[Union[ndarray, csc_matrix]],
+            Optional[Union[ndarray, csc_matrix]],
+            Optional[Union[ndarray, csc_matrix]],
+            Optional[Union[ndarray, csc_matrix]],
+            bool,
+            Optional[str],
+        ],
+        Optional[ndarray],
+    ]
+] = None
+
+piqp_solve_problem: Optional[
+    Callable[
+        [
+            Problem,
+            Optional[Union[ndarray, csc_matrix]],
+            bool,
+            Optional[str],
+        ],
+        Solution,
+    ]
+] = None
+
+try:
+    from .piqp_ import piqp_solve_problem, piqp_solve_qp
+
+    solve_function["piqp"] = piqp_solve_problem
+    available_solvers.append("piqp")
+    dense_solvers.append("piqp")
+    sparse_solvers.append("piqp")
+except ImportError:
+    pass
+
+
 # ProxQP
 # =======
 
@@ -333,6 +506,48 @@ except ImportError:
     pass
 
 
+# QPALM
+# =====
+
+qpalm_solve_qp: Optional[
+    Callable[
+        [
+            Union[ndarray, csc_matrix],
+            Union[ndarray, csc_matrix],
+            Optional[Union[ndarray, csc_matrix]],
+            Optional[Union[ndarray, csc_matrix]],
+            Optional[Union[ndarray, csc_matrix]],
+            Optional[Union[ndarray, csc_matrix]],
+            Optional[Union[ndarray, csc_matrix]],
+            Optional[Union[ndarray, csc_matrix]],
+            Optional[Union[ndarray, csc_matrix]],
+            bool,
+        ],
+        Optional[ndarray],
+    ]
+] = None
+
+qpalm_solve_problem: Optional[
+    Callable[
+        [
+            Problem,
+            Optional[Union[ndarray, csc_matrix]],
+            bool,
+        ],
+        Solution,
+    ]
+] = None
+
+try:
+    from .qpalm_ import qpalm_solve_problem, qpalm_solve_qp
+
+    solve_function["qpalm"] = qpalm_solve_problem
+    available_solvers.append("qpalm")
+    sparse_solvers.append("qpalm")
+except ImportError:
+    pass
+
+
 # qpOASES
 # =======
 
@@ -516,12 +731,17 @@ __all__ = [
     "available_solvers",
     "clarabel_solve_qp",
     "cvxopt_solve_qp",
+    "daqp_solve_qp",
     "dense_solvers",
     "ecos_solve_qp",
     "gurobi_solve_qp",
     "highs_solve_qp",
+    "hpipm_solve_qp",
+    "mosek_solve_qp",
     "osqp_solve_qp",
+    "piqp_solve_qp",
     "proxqp_solve_qp",
+    "qpalm_solve_qp",
     "qpoases_solve_qp",
     "qpswift_solve_qp",
     "quadprog_solve_qp",
