@@ -41,6 +41,7 @@ from ..conversions import (
     socp_from_qp,
     split_dual_linear_box,
 )
+from ..exceptions import ProblemError
 from ..problem import Problem
 from ..solution import Solution
 
@@ -91,6 +92,15 @@ def ecos_solve_problem(
     :
         Solution to the QP, if found, otherwise ``None``.
 
+    Raises
+    ------
+    ProblemError :
+        If inequality constraints contain infinite values that the solver
+        doesn't handle.
+
+    ValueError :
+        If the cost matrix is not positive definite.
+
     Notes
     -----
     All other keyword arguments are forwarded as options to the ECOS solver.
@@ -133,11 +143,7 @@ def ecos_solve_problem(
         G, h = linear_from_box_inequalities(
             G, h, lb, ub, use_sparse=problem.has_sparse
         )
-    kwargs.update(
-        {
-            "verbose": verbose,
-        }
-    )
+    kwargs.update({"verbose": verbose})
     c_socp, G_socp, h_socp, dims = socp_from_qp(P, q, G, h)
     if A is not None:
         A_socp = spa.hstack([A, spa.csc_matrix((A.shape[0], 1))], format="csc")
@@ -147,10 +153,15 @@ def ecos_solve_problem(
     flag = result["info"]["exitFlag"]
     solution = Solution(problem)
     solution.extras = result["info"]
-    if flag != 0:
+    solution.found = flag == 0
+    if not solution.found:
+        if h is not None and not np.isfinite(h).all():
+            raise ProblemError(
+                "ECOS does not handle infinite values in inequality vectors, "
+                "try clipping them to a finite value suitable to your problem"
+            )
         meaning = __exit_flag_meaning__.get(flag, "unknown exit flag")
         warnings.warn(f"ECOS returned exit flag {flag} ({meaning})")
-        return solution
     solution.x = result["x"][:-1]
     if A is not None:
         solution.y = result["y"]
@@ -252,4 +263,4 @@ def ecos_solve_qp(
     """
     problem = Problem(P, q, G, h, A, b, lb, ub)
     solution = ecos_solve_problem(problem, initvals, verbose, **kwargs)
-    return solution.x
+    return solution.x if solution.found else None
