@@ -18,8 +18,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""
-Solver interface for `MOSEK <https://www.mosek.com/>`__.
+"""Solver interface for `MOSEK <https://www.mosek.com/>`__.
 
 MOSEK is a solver for linear, mixed-integer linear, quadratic, mixed-integer
 quadratic, quadratically constraint, conic and convex nonlinear mathematical
@@ -29,14 +28,14 @@ sparse problems, in particular for linear or conic quadratic programs.
 
 from typing import Optional, Union
 
-import cvxopt.msk
 import mosek
 import numpy as np
 import scipy.sparse as spa
 
 from ..problem import Problem
 from ..solution import Solution
-from .cvxopt_ import cvxopt_solve_problem
+from ..solve_unconstrained import solve_unconstrained
+from ..solvers.cvxopt_ import cvxopt_solve_problem
 
 
 def mosek_solve_problem(
@@ -45,22 +44,7 @@ def mosek_solve_problem(
     verbose: bool = False,
     **kwargs,
 ) -> Solution:
-    """
-    Solve a Quadratic Program defined as:
-
-    .. math::
-
-        \\begin{split}\\begin{array}{ll}
-            \\underset{x}{\\mbox{minimize}} &
-                \\frac{1}{2} x^T P x + q^T x \\\\
-            \\mbox{subject to}
-                & G x \\leq h                \\\\
-                & A x = b                    \\\\
-                & lb \\leq x \\leq ub
-        \\end{array}\\end{split}
-
-    using the `MOSEK interface from CVXOPT
-    <https://cvxopt.org/userguide/coneprog.html#optional-solvers>`_.
+    """Solve a quadratic program using MOSEK.
 
     Parameters
     ----------
@@ -90,10 +74,12 @@ def mosek_solve_problem(
     :
         Solution to the QP, if found, otherwise ``None``.
     """
-    original_options = cvxopt.solvers.options
-    cvxopt.solvers.options["mosek"] = {mosek.iparam.log: 1 if verbose else 0}
+    if problem.is_unconstrained:
+        return solve_unconstrained(problem)
+    if "mosek" not in kwargs:
+        kwargs["mosek"] = {}
+    kwargs["mosek"][mosek.iparam.log] = 1 if verbose else 0
     solution = cvxopt_solve_problem(problem, "mosek", initvals, **kwargs)
-    cvxopt.solvers.options = original_options
     return solution
 
 
@@ -110,21 +96,22 @@ def mosek_solve_qp(
     verbose: bool = False,
     **kwargs,
 ) -> Optional[np.ndarray]:
-    """
-    Solve a Quadratic Program defined as:
+    r"""Solve a quadratic program using MOSEK.
+
+    The quadratic program is defined as:
 
     .. math::
 
-        \\begin{split}\\begin{array}{ll}
-            \\underset{x}{\\mbox{minimize}} &
-                \\frac{1}{2} x^T P x + q^T x \\\\
-            \\mbox{subject to}
-                & G x \\leq h                \\\\
-                & A x = b                    \\\\
-                & lb \\leq x \\leq ub
-        \\end{array}\\end{split}
+        \begin{split}\begin{array}{ll}
+            \underset{x}{\mbox{minimize}} &
+                \frac{1}{2} x^T P x + q^T x \\
+            \mbox{subject to}
+                & G x \leq h                \\
+                & A x = b                   \\
+                & lb \leq x \leq ub
+        \end{array}\end{split}
 
-    using the `MOSEK interface from CVXOPT
+    It is solved using the `MOSEK interface from CVXOPT
     <https://cvxopt.org/userguide/coneprog.html#optional-solvers>`_.
 
     Parameters
@@ -157,4 +144,4 @@ def mosek_solve_qp(
     """
     problem = Problem(P, q, G, h, A, b, lb, ub)
     solution = mosek_solve_problem(problem, initvals, verbose, **kwargs)
-    return solution.x
+    return solution.x if solution.found else None
