@@ -156,18 +156,19 @@ def osqp_solve_problem(
         "info": res.info,
         "prim_inf_cert": res.prim_inf_cert,
     }
-    if res.info.status_val != success_status:
+    solution.found = res.info.status_val == success_status
+    if not solution.found:
         warnings.warn(f"OSQP exited with status '{res.info.status}'")
-        return solution
     solution.x = res.x
     m = G.shape[0] if G is not None else 0
     meq = A.shape[0] if A is not None else 0
-    if G is not None:
-        solution.z = res.y[:m]
-    if A is not None:
-        solution.y = res.y[m : m + meq]
-    if lb is not None or ub is not None:
-        solution.z_box = res.y[m + meq :]
+    solution.z = res.y[:m] if G is not None else np.empty((0,))
+    solution.y = res.y[m : m + meq] if A is not None else np.empty((0,))
+    solution.z_box = (
+        res.y[m + meq :]
+        if lb is not None or ub is not None
+        else np.empty((0,))
+    )
     return solution
 
 
@@ -285,4 +286,4 @@ def osqp_solve_qp(
     """
     problem = Problem(P, q, G, h, A, b, lb, ub)
     solution = osqp_solve_problem(problem, initvals, verbose, **kwargs)
-    return solution.x
+    return solution.x if solution.found else None
