@@ -281,25 +281,27 @@ def qpoases_solve_problem(
     solution.extras = {
         "nWSR": n_wsr[0],
     }
+    solution.found = True
     if RET_INIT_FAILED <= return_value <= RET_INIT_FAILED_REGULARISATION:
-        return solution
+        solution.found = False
     if return_value == ReturnValue.MAX_NWSR_REACHED:
         warnings.warn(f"qpOASES reached the maximum number of WSR ({max_wsr})")
-        return solution
+        solution.found = False
 
     x_opt = np.empty((n,))
     z_opt = np.empty((n + C.shape[0],))
     qp.getPrimalSolution(x_opt)  # can't return RET_QP_NOT_SOLVED at this point
     qp.getDualSolution(z_opt)
     solution.x = x_opt
-    m = G.shape[0] if G is not None else 0
-    if lb is not None or ub is not None:
-        solution.z_box = -z_opt[:n]
-    if G is not None:
-        solution.z = -z_opt[n : n + m]
-    if A is not None:
-        solution.y = -z_opt[n + m : n + m + A.shape[0]]
     solution.obj = qp.getObjVal()
+    m = G.shape[0] if G is not None else 0
+    solution.y = (
+        -z_opt[n + m : n + m + A.shape[0]] if A is not None else np.empty((0,))
+    )
+    solution.z = -z_opt[n : n + m] if G is not None else np.empty((0,))
+    solution.z_box = (
+        -z_opt[:n] if lb is not None or ub is not None else np.empty((0,))
+    )
     return solution
 
 
@@ -424,4 +426,4 @@ def qpoases_solve_qp(
         predefined_options,
         **kwargs,
     )
-    return solution.x
+    return solution.x if solution.found else None
