@@ -25,7 +25,7 @@ quadprog is a C implementation of the Goldfarb-Idnani dual algorithm
 """
 
 import warnings
-from typing import Optional, Tuple
+from typing import Optional
 
 import numpy as np
 from numpy import hstack, vstack
@@ -101,79 +101,39 @@ def quadprog_solve_problem(
             qp_b = -h
         meq = 0
 
+    solution = Solution(problem)
     try:
         x, obj, xu, iterations, y, iact = solve_qp(
             qp_G, qp_a, qp_C, qp_b, meq, **kwargs
         )
+        solution.found = True
+        solution.x = x
+        solution.obj = obj
+
+        z, z_box = split_dual_linear_box(y[meq:], lb, ub)
+        solution.y = y[:meq] if meq > 0 else np.empty((0,))
+        solution.z = z
+        solution.z_box = z_box
+
+        solution.extras = {
+            "iact": iact,
+            "iterations": iterations,
+            "xu": xu,
+        }
     except TypeError as error:
         raise ProblemError("problem has sparse matrices") from error
     except ValueError as error:
+        solution.found = False
         error_message = str(error)
         if "matrix G is not positive definite" in error_message:
             # quadprog writes G the cost matrix that we write P in this package
             raise ProblemError("matrix P is not positive definite") from error
-        no_solution = Solution(problem)
-        if "no solution" in error_message:
-            return no_solution
-        warnings.warn(f"quadprog raised a ValueError: {error_message}")
-        return no_solution
+        if "no solution" not in error_message:
+            warnings.warn(f"quadprog raised a ValueError: {error_message}")
 
-    solution = Solution(problem)
-    solution.x = x
-    solution.obj = obj
-
-    z, ys, z_box = __convert_dual_multipliers(y, meq, lb, ub)
-    solution.y = ys
-    solution.z = z
-    solution.z_box = z_box
-
-    solution.extras = {
-        "iact": iact,
-        "iterations": iterations,
-        "xu": xu,
-    }
     return solution
 
 
-def __convert_dual_multipliers(
-    y: np.ndarray,
-    meq: int,
-    lb: Optional[np.ndarray],
-    ub: Optional[np.ndarray],
-) -> Tuple[Optional[np.ndarray], Optional[np.ndarray], Optional[np.ndarray]]:
-    """Convert dual multipliers from quadprog to qpsolvers QP formulation.
-
-    Parameters
-    ----------
-    y :
-        Dual multipliers from quadprog.
-    meq :
-        Number of equality constraints.
-    lb :
-        Lower bound vector for box inequalities, if any.
-    ub :
-        Upper bound vector for box inequalities, if any.
-
-    Returns
-    -------
-    :
-        Tuple of dual multipliers :code:`z, ys, z_box` corresponding
-        respectively to linear inequalities, linear equalities, and box
-        inequalities.
-
-    Raises
-    ------
-    ProblemError :
-        If the problem is ill-formed in some way, for instance if some matrices
-        are not dense.
-    """
-    z, ys, z_box = None, None, None
-    if meq > 0:
-        ys = y[:meq]
-    z, z_box = split_dual_linear_box(y[meq:], lb, ub)
-    return z, ys, z_box
-
-
 def quadprog_solve_qp(
     P: np.ndarray,
     q: np.ndarray,
@@ -234,4 +194,4 @@ def quadprog_solve_qp(
     """
     problem = Problem(P, q, G, h, A, b, lb, ub)
     solution = quadprog_solve_problem(problem, initvals, verbose, **kwargs)
-    return solution.x
+    return solution.x if solution.found else None
