@@ -19,7 +19,7 @@
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
 import numpy as np
-import scipy.sparse as spa
+
 from qpsolvers import Problem
 
 
@@ -38,47 +38,6 @@ def get_sd3310_problem() -> Problem:
     return Problem(P, q, G, h, A, b)
 
 
-def get_sparse_least_squares(n=150_000):
-    """
-    Get a sparse least squares problem.
-
-    Parameters
-    ----------
-    n :
-        Problem size.
-
-    Notes
-    -----
-    This problem was inspired by `this question on Stack Overflow
-    <https://stackoverflow.com/q/73656257/3721564>`__.
-    """
-    # minimize 1/2 || x - s ||^2
-    R = spa.eye(n, format="csc")
-    s = np.array(range(n), dtype=float)
-
-    # such that G * x <= h
-    G = spa.diags(
-        diagonals=[
-            [1.0 if i % 2 == 0 else 0.0 for i in range(n)],
-            [1.0 if i % 3 == 0 else 0.0 for i in range(n - 1)],
-            [1.0 if i % 5 == 0 else 0.0 for i in range(n - 1)],
-        ],
-        offsets=[0, 1, -1],
-        format="csc",
-    )
-    h = np.ones(G.shape[0])
-
-    # such that sum(x) == 42
-    A = spa.csc_matrix(np.ones((1, n)))
-    b = np.array([42.0]).reshape((1,))
-
-    # such that x >= 0
-    lb = np.zeros(n)
-    ub = None
-
-    return R, s, G, h, A, b, lb, ub
-
-
 def get_qpmad_demo_problem():
     """
     Problem from qpmad's `demo.cpp
