@@ -98,10 +98,10 @@ class TestSolveLS(unittest.TestCase):
                 else 2e-5
                 if solver == "proxqp"
                 else 1e-5
-                if solver == "ecos"
+                if solver in ["ecos", "qpalm"]
                 else 1e-6
             )
-            eq_tolerance = 1e-9
+            eq_tolerance = 2e-6 if solver == "qpalm" else 1e-9
             ineq_tolerance = (
                 1e-3
                 if solver == "osqp"
@@ -182,7 +182,7 @@ class TestSolveLS(unittest.TestCase):
         return test
 
     @staticmethod
-    def get_test_medium_sparse(solver: str, sparse_conversion: bool):
+    def get_test_medium_sparse(solver: str, sparse_conversion: bool, **kwargs):
         """Get test function for a large sparse problem with a given solver.
 
         Parameters
@@ -199,7 +199,7 @@ class TestSolveLS(unittest.TestCase):
         """
 
         def test(self):
-            R, s, G, h, A, b, lb, ub = get_sparse_least_squares(n=1500)
+            R, s, G, h, A, b, _, _ = get_sparse_least_squares(n=1500)
             x = solve_ls(
                 R,
                 s,
@@ -209,19 +209,30 @@ class TestSolveLS(unittest.TestCase):
                 b,
                 solver=solver,
                 sparse_conversion=sparse_conversion,
+                **kwargs,
             )
             self.assertIsNotNone(x)
 
         return test
 
     @staticmethod
-    def get_test_large_sparse(solver: str, sparse_conversion: bool):
+    def get_test_large_sparse(
+        solver: str,
+        sparse_conversion: bool,
+        obj_scaling: float = 1.0,
+        **kwargs,
+    ):
         """Get test function for a large sparse problem with a given solver.
 
         Parameters
         ----------
         solver :
             Name of the solver to test.
+        sparse_conversion :
+            Whether to perform sparse or dense LS-to-QP conversion.
+        obj_scaling:
+            Scale objective matrices by this factor. Suitable values can help
+            solvers that don't compute a preconditioner internally.
 
         Returns
         -------
@@ -230,16 +241,17 @@ class TestSolveLS(unittest.TestCase):
         """
 
         def test(self):
-            R, s, G, h, A, b, lb, ub = get_sparse_least_squares(n=15_000)
+            R, s, G, h, A, b, _, _ = get_sparse_least_squares(n=15_000)
             x = solve_ls(
-                R,
-                s,
+                obj_scaling * R,
+                obj_scaling * s,
                 G,
                 h,
                 A,
                 b,
                 solver=solver,
                 sparse_conversion=sparse_conversion,
+                **kwargs,
             )
             self.assertIsNotNone(x)
 
@@ -251,38 +263,64 @@ for solver in available_solvers:
     setattr(
         TestSolveLS, "test_{}".format(solver), TestSolveLS.get_test(solver)
     )
+
 for solver in sparse_solvers:
     setattr(
         TestSolveLS,
         "test_mixed_sparse_args_{}".format(solver),
         TestSolveLS.get_test_mixed_sparse_args(solver),
     )
+
+for solver in sparse_solvers:  # loop complexity warning ;p
     if solver != "gurobi":
         # Gurobi: model too large for size-limited license
+        kwargs = {}
+        if solver == "mosek":
+            try:
+                import mosek
+
+                kwargs["mosek"] = {mosek.dparam.intpnt_qo_tol_rel_gap: 1e-6}
+            except ImportError:
+                pass
         setattr(
             TestSolveLS,
             "test_medium_sparse_dense_conversion_{}".format(solver),
             TestSolveLS.get_test_medium_sparse(
-                solver, sparse_conversion=False
+                solver, sparse_conversion=False, **kwargs
             ),
         )
-        if solver != "cvxopt":
-            # CVXOPT: sparse conversion breaks rank assumption
-            setattr(
-                TestSolveLS,
-                "test_medium_sparse_sparse_conversion_{}".format(solver),
-                TestSolveLS.get_test_medium_sparse(
-                    solver, sparse_conversion=True
-                ),
-            )
-    if solver not in ["gurobi", "highs", "scs"]:
+
+for solver in sparse_solvers:  # loop complexity warning ;p
+    if solver not in ["cvxopt", "gurobi"]:
+        # CVXOPT: sparse conversion breaks rank assumption
+        # Gurobi: model too large for size-limited license
+        setattr(
+            TestSolveLS,
+            "test_medium_sparse_sparse_conversion_{}".format(solver),
+            TestSolveLS.get_test_medium_sparse(solver, sparse_conversion=True),
+        )
+
+for solver in sparse_solvers:  # loop complexity warning ;p
+    if solver not in ["gurobi", "highs"]:
         # Gurobi: model too large for size-limited license
         # HiGHS: model too large https://github.com/ERGO-Code/HiGHS/issues/992
-        # SCS: issue reported in https://github.com/cvxgrp/scs/issues/234
+        kwargs = {"eps_infeas": 1e-12} if solver == "scs" else {}
+        if solver == "mosek":
+            try:
+                import mosek
+
+                kwargs["mosek"] = {mosek.dparam.intpnt_qo_tol_rel_gap: 1e-7}
+            except ImportError:
+                pass
         setattr(
             TestSolveLS,
             "test_large_sparse_problem_dense_conversion_{}".format(solver),
-            TestSolveLS.get_test_large_sparse(solver, sparse_conversion=False),
+            TestSolveLS.get_test_large_sparse(
+                solver,
+                sparse_conversion=False,
+                obj_scaling=1e-3 if solver == "mosek" else 1.0,
+                **kwargs,
+            ),
         )
         if solver != "cvxopt":
             # CVXOPT: sparse conversion breaks rank assumption
@@ -292,6 +330,6 @@ for solver in sparse_solvers:
                     solver
                 ),
                 TestSolveLS.get_test_large_sparse(
-                    solver, sparse_conversion=True
+                    solver, sparse_conversion=True, **kwargs
                 ),
             )
