@@ -20,21 +20,19 @@
 
 """Unit tests for the `solve_problem` function."""
 
-import math
 import unittest
 
 import numpy as np
 from numpy.linalg import norm
 
 from qpsolvers import available_solvers, solve_problem
-
-from .solved_problems import (
-    get_maros_meszaros_qptest,
+from qpsolvers.problems import (
     get_qpsut01,
     get_qpsut02,
     get_qpsut03,
     get_qpsut04,
     get_qpsut05,
+    get_qptest,
 )
 
 
@@ -65,18 +63,21 @@ class TestSolveProblem(unittest.TestCase):
         """
 
         def test(self):
-            ref_solution = get_qpsut01()
-            problem = ref_solution.problem
+            problem, ref_solution = get_qpsut01()
             solution = solve_problem(problem, solver=solver)
             eps_abs = (
                 5e-1
-                if solver == "osqp"
+                if solver in ["osqp", "qpalm"]
                 else 5e-3
                 if solver == "proxqp"
                 else 1e-4
                 if solver == "ecos"
+                else 5e-5
+                if solver == "mosek"
                 else 1e-6
                 if solver in ["cvxopt", "qpswift", "scs"]
+                else 5e-7
+                if solver == "gurobi"
                 else 1e-7
             )
             self.assertLess(norm(solution.x - ref_solution.x), eps_abs)
@@ -105,12 +106,11 @@ class TestSolveProblem(unittest.TestCase):
         """
 
         def test(self):
-            ref_solution = get_qpsut02()
-            problem = ref_solution.problem
+            problem, ref_solution = get_qpsut02()
             solution = solve_problem(problem, solver=solver)
             eps_abs = (
                 5e-2
-                if solver == "ecos"
+                if solver in ["ecos", "qpalm"]
                 else 5e-4
                 if solver in ["proxqp", "scs"]
                 else 1e-4
@@ -118,7 +118,7 @@ class TestSolveProblem(unittest.TestCase):
                 else 1e-5
                 if solver in ["highs", "osqp"]
                 else 5e-7
-                if solver in ["clarabel", "qpswift"]
+                if solver in ["clarabel", "mosek", "qpswift", "piqp"]
                 else 1e-7
                 if solver == "gurobi"
                 else 1e-8
@@ -146,10 +146,22 @@ class TestSolveProblem(unittest.TestCase):
         """
 
         def test(self):
-            ref_solution = get_qpsut03()
-            problem = ref_solution.problem
+            problem, ref_solution = get_qpsut03()
             solution = solve_problem(problem, solver=solver)
-            self.assertFalse(math.isnan(solution.duality_gap()))
+            self.assertEqual(solution.x.shape, (4,))
+            self.assertEqual(solution.y.shape, (0,))
+            self.assertEqual(solution.z.shape, (0,))
+            self.assertEqual(solution.z_box.shape, (4,))
+            self.assertAlmostEqual(
+                np.linalg.norm(solution.z_box),
+                0.0,
+                places=3
+                if solver == "cvxopt"
+                else 5
+                if solver == "mosek"
+                else 7,
+            )
+            self.assertTrue(np.isfinite(solution.duality_gap()))
 
         return test
 
@@ -170,10 +182,9 @@ class TestSolveProblem(unittest.TestCase):
         """
 
         def test(self):
-            ref_solution = get_qpsut04()
-            problem = ref_solution.problem
+            problem, ref_solution = get_qpsut04()
             solution = solve_problem(problem, solver=solver)
-            eps_abs = 2e-4 if solver == "osqp" else 1e-6
+            eps_abs = 2e-4 if solver in ["osqp", "qpalm"] else 1e-6
             self.assertLess(norm(solution.x - ref_solution.x), eps_abs)
             self.assertLess(norm(solution.z - ref_solution.z), eps_abs)
             self.assertTrue(np.isfinite(solution.duality_gap()))
@@ -197,8 +208,7 @@ class TestSolveProblem(unittest.TestCase):
         """
 
         def test(self):
-            ref_solution = get_qpsut05()
-            problem = ref_solution.problem
+            problem, ref_solution = get_qpsut05()
             solution = solve_problem(problem, solver=solver)
             eps_abs = 2e-5 if solver == "ecos" else 1e-6
             self.assertLess(norm(solution.x - ref_solution.x), eps_abs)
@@ -207,7 +217,7 @@ class TestSolveProblem(unittest.TestCase):
         return test
 
     @staticmethod
-    def get_test_maros_meszaros_qptest(solver):
+    def get_test_qptest(solver):
         """Get test function for the QPTEST problem.
 
         Parameters
@@ -226,8 +236,7 @@ class TestSolveProblem(unittest.TestCase):
         """
 
         def test(self):
-            solution = get_maros_meszaros_qptest()
-            problem = solution.problem
+            problem, solution = get_qptest()
             result = solve_problem(problem, solver=solver)
             tolerance = (
                 1e1
@@ -237,7 +246,9 @@ class TestSolveProblem(unittest.TestCase):
                 else 2e-3
                 if solver == "osqp"
                 else 5e-5
-                if solver == "scs"
+                if solver in ["qpalm", "scs"]
+                else 1e-6
+                if solver == "mosek"
                 else 1e-7
                 if solver == "highs"
                 else 5e-7
@@ -271,7 +282,7 @@ class TestSolveProblem(unittest.TestCase):
         """
 
         def test(self):
-            problem = get_qpsut01().problem
+            problem, _ = get_qpsut01()
             problem.lb[1] = -np.inf
             problem.ub[1] = +np.inf
             result = solve_problem(problem, solver=solver)
@@ -297,7 +308,7 @@ class TestSolveProblem(unittest.TestCase):
         """
 
         def test(self):
-            problem = get_qpsut01().problem
+            problem, _ = get_qpsut01()
             problem.h[0] = +np.inf
             result = solve_problem(problem, solver=solver)
             self.assertIsNotNone(result.x)
@@ -319,11 +330,15 @@ for solver in available_solvers:
         f"test_qpsut02_{solver}",
         TestSolveProblem.get_test_qpsut02(solver),
     )
-    setattr(
-        TestSolveProblem,
-        f"test_qpsut03_{solver}",
-        TestSolveProblem.get_test_qpsut03(solver),
-    )
+    if solver not in ["ecos", "mosek", "qpswift"]:
+        # ECOS: https://github.com/embotech/ecos-python/issues/49
+        # MOSEK: https://github.com/qpsolvers/qpsolvers/issues/229
+        # qpSWIFT: https://github.com/qpsolvers/qpsolvers/issues/159
+        setattr(
+            TestSolveProblem,
+            f"test_qpsut03_{solver}",
+            TestSolveProblem.get_test_qpsut03(solver),
+        )
     setattr(
         TestSolveProblem,
         f"test_qpsut04_{solver}",
@@ -337,12 +352,12 @@ for solver in available_solvers:
             TestSolveProblem.get_test_qpsut05(solver),
         )
     if solver not in ["ecos", "qpswift"]:
-        # See https://github.com/qpsolvers/qpsolvers/issues/159
-        # See https://github.com/qpsolvers/qpsolvers/issues/160
+        # ECOS: https://github.com/qpsolvers/qpsolvers/issues/160
+        # qpSWIFT: https://github.com/qpsolvers/qpsolvers/issues/159
         setattr(
             TestSolveProblem,
-            f"test_maros_meszaros_qptest_{solver}",
-            TestSolveProblem.get_test_maros_meszaros_qptest(solver),
+            f"test_qptest_{solver}",
+            TestSolveProblem.get_test_qptest(solver),
         )
     if solver not in ["ecos", "qpswift"]:
         # See https://github.com/qpsolvers/qpsolvers/issues/159
