@@ -155,7 +155,7 @@ class TestSolveQP(unittest.TestCase):
                 2e-4
                 if solver == "osqp"
                 else 5e-4
-                if solver == "scs"
+                if solver in ["qpalm", "scs"]
                 else 1e-4
                 if solver == "ecos"
                 else 5e-6
@@ -165,7 +165,7 @@ class TestSolveQP(unittest.TestCase):
             eq_tolerance = 1e-10
             ineq_tolerance = (
                 2e-4
-                if solver == "scs"
+                if solver in ["qpalm", "scs"]
                 else 5e-6
                 if solver == "proxqp"
                 else 1e-10
@@ -226,11 +226,23 @@ class TestSolveQP(unittest.TestCase):
                 for (lb_case, ub_case) in box_variants
             ]
 
-            for (i, test_case) in enumerate(cases):
+            for i, test_case in enumerate(cases):
                 no_inequality = "G" not in test_case or test_case["G"] is None
                 if no_inequality and solver == "qpswift":
                     # QPs without inequality constraints not handled by qpSWIFT
                     continue
+                has_one_equality = (
+                    "A" in test_case
+                    and test_case["A"] is not None
+                    and test_case["A"].ndim == 1
+                )
+                has_lower_box = (
+                    "lb" in test_case and test_case["lb"] is not None
+                )
+                if has_one_equality and has_lower_box and solver == "hpipm":
+                    # Skipping this test for HPIPM for now
+                    # See https://github.com/giaf/hpipm/issues/136
+                    continue
                 test_comp = {
                     k: v.shape if v is not None else "None"
                     for k, v in test_case.items()
@@ -247,7 +259,7 @@ class TestSolveQP(unittest.TestCase):
                     else 1e-3
                     if solver == "scs"
                     else 2e-3
-                    if solver == "osqp"
+                    if solver in ["osqp", "qpalm"]
                     else 5e-4
                     if solver == "ecos"
                     else 2e-4
@@ -292,7 +304,7 @@ class TestSolveQP(unittest.TestCase):
                 else 5e-5
                 if solver == "scs"
                 else 1e-6
-                if solver == "ecos"
+                if solver in ["qpalm", "ecos"]
                 else 1e-8
             )
             eq_tolerance = 1e-5 if solver == "proxqp" else 1e-10
@@ -330,7 +342,7 @@ class TestSolveQP(unittest.TestCase):
                 1e-3
                 if solver == "ecos"
                 else 1e-5
-                if solver == "osqp"
+                if solver in ["osqp", "qpalm"]
                 else 1e-6
             )
             self.assertLess(norm(x - known_solution), sol_tolerance)
@@ -362,6 +374,8 @@ class TestSolveQP(unittest.TestCase):
             sol_tolerance = (
                 1e-3
                 if solver == "ecos"
+                else 5e-5
+                if solver == "qpalm"
                 else 2e-6
                 if solver == "osqp"
                 else 1e-6
@@ -404,7 +418,7 @@ class TestSolveQP(unittest.TestCase):
             known_solution = array([0.28026906, -1.55156951, 2.27130045])
             sol_tolerance = (
                 5e-4
-                if solver == "osqp"
+                if solver in ["osqp", "qpalm"]
                 else 1e-5
                 if solver in ["ecos", "scs"]
                 else 1e-6
@@ -444,7 +458,9 @@ class TestSolveQP(unittest.TestCase):
             self.assertIsNotNone(x)
             known_solution = array([0.30769231, -0.69230769, 1.38461538])
             sol_tolerance = (
-                5e-4
+                1e-3
+                if solver == "qpalm"
+                else 5e-4
                 if solver == "osqp"
                 else 1e-5
                 if solver == "scs"
@@ -456,7 +472,13 @@ class TestSolveQP(unittest.TestCase):
                 if solver == "qpswift"
                 else 1e-8
             )
-            eq_tolerance = 5e-10 if solver in ["osqp", "scs"] else 1e-10
+            eq_tolerance = (
+                1e-4
+                if solver == "qpalm"
+                else 5e-10
+                if solver in ["osqp", "scs"]
+                else 1e-10
+            )
             ineq_tolerance = (
                 5e-6
                 if solver == "proxqp"
@@ -499,11 +521,11 @@ class TestSolveQP(unittest.TestCase):
                 5e-3
                 if solver == "cvxopt"
                 else 2e-3
-                if solver == "osqp"
+                if solver in ["osqp", "qpalm"]
                 else 1e-3
-                if solver == "gurobi"
+                if solver in ["gurobi", "piqp"]
                 else 5e-4
-                if solver == "clarabel"
+                if solver in ["clarabel", "mosek"]
                 else 1e-4
                 if solver == "scs"
                 else 2e-5
@@ -514,7 +536,7 @@ class TestSolveQP(unittest.TestCase):
             )
             ineq_tolerance = (
                 1e-4
-                if solver == "scs"
+                if solver in ["qpalm", "scs"]
                 else 2e-5
                 if solver == "proxqp"
                 else 5e-7
@@ -555,9 +577,9 @@ class TestSolveQP(unittest.TestCase):
                 1e-3
                 if solver == "gurobi"
                 else 1e-3
-                if solver == "osqp"
+                if solver in ["osqp", "qpalm"]
                 else 5e-6
-                if solver == "proxqp"
+                if solver in ["mosek", "proxqp"]
                 else 1e-7
                 if solver in ["cvxopt", "scs"]
                 else 1e-8
@@ -634,7 +656,7 @@ class TestSolveQP(unittest.TestCase):
             self.assertIsNotNone(x)
             sol_tolerance = (
                 5e-4
-                if solver == "scs"
+                if solver in ["qpalm", "scs"]
                 else 2e-4
                 if solver == "osqp"
                 else 1e-4
@@ -646,7 +668,7 @@ class TestSolveQP(unittest.TestCase):
             eq_tolerance = 1e-4 if solver == "osqp" else 1e-10
             ineq_tolerance = (
                 2e-4
-                if solver in ["osqp", "scs"]
+                if solver in ["osqp", "qpalm", "scs"]
                 else 5e-6
                 if solver == "proxqp"
                 else 1e-10
@@ -738,11 +760,11 @@ class TestSolveQP(unittest.TestCase):
                 2e-3
                 if solver == "osqp"
                 else 5e-4
-                if solver == "scs"
+                if solver in ["qpalm", "scs"]
                 else 2e-5
                 if solver == "proxqp"
                 else 1e-6
-                if solver in ["cvxopt", "qpswift"]
+                if solver in ["cvxopt", "mosek", "qpswift", "piqp"]
                 else 1e-8
             )
             self.assertIsNotNone(x)
@@ -765,7 +787,7 @@ for solver in available_solvers:
         TestSolveQP.get_test_bounds(solver),
     )
     if solver != "qpswift":
-        # QPs without inequality constraints are not handled by qpSWIFT
+        # qpSWIFT: https://github.com/qpSWIFT/qpSWIFT/issues/2
         setattr(
             TestSolveQP,
             f"test_no_cons_{solver}",
@@ -777,7 +799,7 @@ for solver in available_solvers:
         TestSolveQP.get_test_no_eq(solver),
     )
     if solver != "qpswift":
-        # QPs without inequality constraints are not handled by qpSWIFT
+        # qpSWIFT: https://github.com/qpSWIFT/qpSWIFT/issues/2
         setattr(
             TestSolveQP,
             f"test_no_ineq_{solver}",
